clc;
clear;
syms y(t) x(t) tau s Ly X(s) H(s) H2 x u fgh
syms R C L n w k kF real

% Task A
dT(t) = diff(y(t),t);                               % y'(t)
eq = L*dT(t) + R*y(t) + 1/C * int(y(tau),0,t);      % hela ekvationen
Xseq = laplace(eq,t,s);                             % laplace on equation X(s)
pretty(simplify(Xseq));                             % simplify

Leq2=subs(Xseq,{'laplace(y(t),t,s)','y(0)','D(y)(0)'},{Ly,0,0});     % apply initial conditions & Ly = laplace(y)
pretty(simplify(Leq2));                                              % X(s) pretty
Ly=solve(Leq2==X(s),Ly);                                             % Y(s)

H = Ly/X(s)

% Task B

% Transfer function : s / ( L*s^2 + R*s + 1/C ) 
%
% Routh-Hurwitz criterion
% s^2   L     1/C    0
% s^1   R     0      0
% s^0   1/C   0      0
%
% for stability right column must be true for all positive values, 
% which shows that the system is stable for all positive values of R,L,C.

% Task C

H2 = w*1i/(-L*w^2 + 1i*w*R + 1/C);

% Task D
% Frequency will never be zero beacuse H(jw) cannot be zero
% DC implies zero frequency

clc;
clear;
% Task E
f0=50;                                                      % Input frequency
T0=1/f0;                                                    % period
T=5*T0;                                                     % Time sampling
N=1000;                                                     % Number of time points
dt=T/N;
t2=0:dt:T-dt;                                               % Time domain 10*T0
fs=1/dt;                                                    % sampling frequency
fre=0:fs/N:fs-fs/N;                                         % Frequency domain
W=2*pi*fre;
x = 5+5*square(2*pi*50*t2);
grid on;
figure(1);
hold on
xlabel('Time (s)');

X = fft(x);
% F, G
syms s
syms R L C t w0 f w k

% CONSTANTS
R = 5;
L = 40 * 10^-3;
C = 10 * 10^-6;
H_c = (1i*W) ./ (L*(1i*W).^2 + 1i*W*R + (1/C));
Y = X.*H_c;
y = ifft(Y);
[P, h1, h2] = plotyy(t2, x, t2, real(y)/1000);
set(h1, 'color', 'blue');
set(h2, 'color','red');
set(get(P(1),'Ylabel'),'String','Input (V)');
set(get(P(2),'Ylabel'),'String','Output (A)');


% Uppgift H
H_f = (1i*W) ./ (L*(1i*W).^2 + 1i*W*R + (1/C));
figure(123)
grid on;
plot(fre, abs(H_f));
xlim([0 2000]);
ylim([0 0.3]);
xlabel('Freq');
ylabel('Amplitude');

% Uppgift I
% CONSTANTS
R = 1000;
L = 1 * 10^-3;
C = 1 * 10^-3;
H_i = (1i*W) ./ (L*(1i*W).^2 + 1i*W*R + (1/C));
Y = X.*H_i;
y = ifft(Y);
figure(2823)
grid on;
%plot(t2, real(y))
[P, h1, h2] = plotyy(t2, x, t2, real(y)/N);
set(h1, 'color', 'blue');
set(h2, 'color','red');
set(get(P(1),'Ylabel'),'String','Input (V)');
set(get(P(2),'Ylabel'),'String','Output (A)');
title('Task i');

% Uppgift J
figure(1234)
H_j = (1i*W) ./ (L*(1i*W).^2 + 1i*W*R + (1/C));
grid on;
[H,w] = freqz(Y,X);        % Compute frequency response H(w)
subplot(2,1,1);
plot(fre, abs(H_j));
subplot(2,1,2);
plot(t2, angle(H_j));